@@ -21,6 +21,8 @@ import subprocess
 import sys
 import tempfile
 
+import ansible.constants
+
 from kayobe import exception
 from kayobe import utils
 from kayobe import vault
@@ -77,6 +79,9 @@ def add_args(parser):
                         action="store_true",
                         help="only print names of tasks, don't run them, "
                              "note this has no affect on kolla-ansible.")
+    parser.add_argument("-sh", "--skip-hooks", action="store", default=None,
+                        help="disables hooks. Specify a pattern to skip"
+                             "specific playbooks. \"all\" skips all playbooks")
 
 
 def _get_kayobe_environment_path(parsed_args):
@@ -91,10 +96,11 @@ def _get_kayobe_environment_path(parsed_args):
 
 def _get_inventories_paths(parsed_args, env_path):
     """Return the paths to the Kayobe inventories."""
+    default_inventory = utils.get_data_files_path("ansible", "inventory")
+    inventories = [default_inventory]
     if parsed_args.inventory:
-        return parsed_args.inventory
+        inventories.extend(parsed_args.inventory)
     else:
-        inventories = []
         shared_inventory = os.path.join(parsed_args.config_path, "inventory")
         if env_path:
             if os.path.exists(shared_inventory):
@@ -106,12 +112,12 @@ def _get_inventories_paths(parsed_args, env_path):
             # Preserve existing behaviour: don't check if an inventory
             # directory exists when no environment is specified
             inventories.append(shared_inventory)
-        return inventories
+    return inventories
 
 
 def _validate_args(parsed_args, playbooks):
     """Validate Kayobe Ansible arguments."""
-    vault.validate_args(parsed_args)
+    vault.enforce_single_password_source(parsed_args)
     result = utils.is_readable_dir(parsed_args.config_path)
     if not result["result"]:
         LOG.error("Kayobe configuration path %s is invalid: %s",
@@ -227,6 +233,40 @@ def _get_environment(parsed_args):
     ansible_cfg_path = os.path.join(parsed_args.config_path, "ansible.cfg")
     if utils.is_readable_file(ansible_cfg_path)["result"]:
         env.setdefault("ANSIBLE_CONFIG", ansible_cfg_path)
+
+    # Update various role, collection and plugin paths to include the Kayobe
+    # roles, collections and plugins. This allows custom playbooks to use these
+    # resources.
+    roles_paths = [
+        os.path.join(parsed_args.config_path, "ansible", "roles"),
+        utils.get_data_files_path("ansible", "roles"),
+    ] + ansible.constants.DEFAULT_ROLES_PATH
+    env.setdefault("ANSIBLE_ROLES_PATH", ":".join(roles_paths))
+
+    collections_paths = [
+        os.path.join(parsed_args.config_path, "ansible", "collections"),
+        utils.get_data_files_path("ansible", "collections"),
+    ] + ansible.constants.COLLECTIONS_PATHS
+    env.setdefault("ANSIBLE_COLLECTIONS_PATH", ":".join(collections_paths))
+
+    action_plugins = [
+        os.path.join(parsed_args.config_path, "ansible", "action_plugins"),
+        utils.get_data_files_path("ansible", "action_plugins"),
+    ] + ansible.constants.DEFAULT_ACTION_PLUGIN_PATH
+    env.setdefault("ANSIBLE_ACTION_PLUGINS", ":".join(action_plugins))
+
+    filter_plugins = [
+        os.path.join(parsed_args.config_path, "ansible", "filter_plugins"),
+        utils.get_data_files_path("ansible", "filter_plugins"),
+    ] + ansible.constants.DEFAULT_FILTER_PLUGIN_PATH
+    env.setdefault("ANSIBLE_FILTER_PLUGINS", ":".join(filter_plugins))
+
+    test_plugins = [
+        os.path.join(parsed_args.config_path, "ansible", "test_plugins"),
+        utils.get_data_files_path("ansible", "test_plugins"),
+    ] + ansible.constants.DEFAULT_TEST_PLUGIN_PATH
+    env.setdefault("ANSIBLE_TEST_PLUGINS", ":".join(test_plugins))
+
     return env
 
 
